@@ -3,11 +3,12 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::PodSpellingTests;
-our $VERSION = '1.100690';
-# ABSTRACT: release tests for POD spelling
+BEGIN {
+  $Dist::Zilla::Plugin::PodSpellingTests::VERSION = '1.101420';
+}
+# ABSTRACT: Release tests for POD spelling
 use Moose;
 use Pod::Wordlist::hanekomu;
-use Test::Spelling;
 extends 'Dist::Zilla::Plugin::InlineFiles';
 
 __PACKAGE__->meta->make_immutable;
@@ -21,11 +22,11 @@ no Moose;
 
 =head1 NAME
 
-Dist::Zilla::Plugin::PodSpellingTests - release tests for POD spelling
+Dist::Zilla::Plugin::PodSpellingTests - Release tests for POD spelling
 
 =head1 VERSION
 
-version 1.100690
+version 1.101420
 
 =head1 SYNOPSIS
 
@@ -36,14 +37,36 @@ In C<dist.ini>:
 =head1 DESCRIPTION
 
 This is an extension of L<Dist::Zilla::Plugin::InlineFiles>, providing the
-following files
+following file:
 
   xt/release/pod-spell.t - a standard Test::Spelling test
 
+=for test_synopsis 1;
+__END__
+
 =head1 INSTALLATION
 
 See perlmodinstall for information and options on installing Perl modules.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-PodSpellingTests>.
+
+=head1 AVAILABILITY
+
+The latest version of this module is available from the Comprehensive Perl
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Dist-Zilla-Plugin-PodSpellingTests/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Dist-Zilla-Plugin-PodSpellingTests/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHOR
 
   Marcel Gruenauer <marcel@cpan.org>
